# Contributing

## Issues

Please report bugs and other issues as [GitHub issues](https://github.com/astro-pi/astro-pi-hat/issues) ensuring to give as much detail about your problem as possible.

## Pull Requests

Please create a new pull request for each change recommendation.

## Policy

- Python 2/3 compatability
- PEP8-compliance
